pub struct SwitchingTransport {
pub(crate) current_transport: Arc<RwLock<SingleTransport>>,
pub(crate) urls: Arc<Vec<Url>>,
pub(crate) opt: Arc<L1ClientOptions>,
pub(crate) metrics: L1ClientMetrics,
pub(crate) switch_notify: Arc<Notify>,
}Expand description
An RPC client with multiple remote (HTTP) providers.
This client utilizes one RPC provider at a time, but if it detects that the provider is in a failing state, it will automatically switch to the next provider in its list.
Fields
current_transport: Arc<RwLock<SingleTransport>>The transport currently being used by the client
urls: Arc<Vec<Url>>The list of configured HTTP URLs to use for RPC requests
opt: Arc<L1ClientOptions>metrics: L1ClientMetricsswitch_notify: Arc<Notify>Implementations
Sourceimpl SwitchingTransport
impl SwitchingTransport
Sourcepub fn new(opt: L1ClientOptions, urls: Vec<Url>) -> Result<Self>
pub fn new(opt: L1ClientOptions, urls: Vec<Url>) -> Result<Self>
Create a new SwitchingTransport with the given options and URLs
Sourceasync fn wait_switch(&self)
async fn wait_switch(&self)
Returns when the transport has been switched
fn options(&self) -> &L1ClientOptions
fn metrics(&self) -> &L1ClientMetrics
Sourceimpl SwitchingTransport
impl SwitchingTransport
fn switch_to( &self, next_gen: usize, current_transport: SingleTransport, ) -> SingleTransport